summaryrefslogtreecommitdiffstats
path: root/kjsembed/qtbindings/qcanvastext_imp.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/qtbindings/qcanvastext_imp.cpp')
-rw-r--r--kjsembed/qtbindings/qcanvastext_imp.cpp68
1 files changed, 34 insertions, 34 deletions
diff --git a/kjsembed/qtbindings/qcanvastext_imp.cpp b/kjsembed/qtbindings/qcanvastext_imp.cpp
index bb1c00ce..d0528647 100644
--- a/kjsembed/qtbindings/qcanvastext_imp.cpp
+++ b/kjsembed/qtbindings/qcanvastext_imp.cpp
@@ -23,12 +23,12 @@
*/
namespace KJSEmbed {
-TTQCanvasTextImp::TQCanvasTextImp( KJS::ExecState *exec, int mid, bool constructor )
+TQCanvasTextImp::TQCanvasTextImp( KJS::ExecState *exec, int mid, bool constructor )
: JSProxyImp(exec), id(mid), cons(constructor)
{
}
-TTQCanvasTextImp::~TQCanvasTextImp()
+TQCanvasTextImp::~TQCanvasTextImp()
{
}
@@ -43,7 +43,7 @@ void TQCanvasTextImp::addStaticBindings( KJS::ExecState *exec, KJS::Object &obje
};
int idx = 0;
- TTQCString lastName;
+ TQCString lastName;
while( methods[idx].name ) {
if ( lastName != methods[idx].name ) {
@@ -80,7 +80,7 @@ void TQCanvasTextImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
};
int idx = 0;
- TTQCString lastName;
+ TQCString lastName;
while( methods[idx].name ) {
if ( lastName != methods[idx].name ) {
@@ -93,25 +93,25 @@ void TQCanvasTextImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
}
/**
* Extract a TTQCanvasText pointer from an Object.
*/
-TTQCanvasText *TQCanvasTextImp::toTQCanvasText( KJS::Object &self )
+TQCanvasText *TQCanvasTextImp::toTQCanvasText( KJS::Object &self )
{
JSObjectProxy *ob = JSProxy::toObjectProxy( self.imp() );
if ( ob ) {
- TTQObject *obj = ob->object();
+ TQObject *obj = ob->object();
if ( obj )
- return dynamic_cast<TTQCanvasText *>( obj );
+ return dynamic_cast<TQCanvasText *>( obj );
}
JSOpaqueProxy *op = JSProxy::toOpaqueProxy( self.imp() );
if ( !op )
return 0;
- if ( op->typeName() != "TTQCanvasText" )
+ if ( op->typeName() != "TQCanvasText" )
return 0;
- return op->toNative<TTQCanvasText>();
+ return op->toNative<TQCanvasText>();
}
/**
@@ -137,7 +137,7 @@ KJS::Object TQCanvasTextImp::construct( KJS::ExecState *exec, const KJS::List &a
break;
}
- TTQString msg = i18n("TQCanvasTextCons has no constructor with id '%1'.").arg(id);
+ TQString msg = i18n("TQCanvasTextCons has no constructor with id '%1'.").arg(id);
return throwError(exec, msg,KJS::ReferenceError);
}
@@ -145,15 +145,15 @@ KJS::Object TQCanvasTextImp::construct( KJS::ExecState *exec, const KJS::List &a
KJS::Object TQCanvasTextImp::TQCanvasText_1( KJS::ExecState *exec, const KJS::List &args )
{
- // Unsupported parameter TTQCanvas *
+ // Unsupported parameter TQCanvas *
return KJS::Object();
- TTQCanvas * arg0; // Dummy
+ TQCanvas * arg0; // Dummy
- // We should now create an instance of the TTQCanvasText object
+ // We should now create an instance of the TQCanvasText object
- TTQCanvasText *ret = new TTQCanvasText(
+ TQCanvasText *ret = new TQCanvasText(
arg0 );
@@ -163,17 +163,17 @@ KJS::Object TQCanvasTextImp::TQCanvasText_1( KJS::ExecState *exec, const KJS::Li
KJS::Object TQCanvasTextImp::TQCanvasText_2( KJS::ExecState *exec, const KJS::List &args )
{
- TTQString arg0 = extractTQString(exec, args, 0);
+ TQString arg0 = extractTQString(exec, args, 0);
- // Unsupported parameter TTQCanvas *
+ // Unsupported parameter TQCanvas *
return KJS::Object();
- TTQCanvas * arg1; // Dummy
+ TQCanvas * arg1; // Dummy
- // We should now create an instance of the TTQCanvasText object
+ // We should now create an instance of the TQCanvasText object
- TTQCanvasText *ret = new TTQCanvasText(
+ TQCanvasText *ret = new TQCanvasText(
arg0,
arg1 );
@@ -184,22 +184,22 @@ KJS::Object TQCanvasTextImp::TQCanvasText_2( KJS::ExecState *exec, const KJS::Li
KJS::Object TQCanvasTextImp::TQCanvasText_3( KJS::ExecState *exec, const KJS::List &args )
{
- TTQString arg0 = extractTQString(exec, args, 0);
+ TQString arg0 = extractTQString(exec, args, 0);
// Unsupported parameter TQFont
return KJS::Object();
- TTQFont arg1; // Dummy
+ TQFont arg1; // Dummy
- // Unsupported parameter TTQCanvas *
+ // Unsupported parameter TQCanvas *
return KJS::Object();
- TTQCanvas * arg2; // Dummy
+ TQCanvas * arg2; // Dummy
- // We should now create an instance of the TTQCanvasText object
+ // We should now create an instance of the TQCanvasText object
- TTQCanvasText *ret = new TTQCanvasText(
+ TQCanvasText *ret = new TQCanvasText(
arg0,
arg1,
@@ -266,7 +266,7 @@ KJS::Value TQCanvasTextImp::call( KJS::ExecState *exec, KJS::Object &self, const
break;
}
- TTQString msg = i18n( "TQCanvasTextImp has no method with id '%1'." ).arg( id );
+ TQString msg = i18n( "TQCanvasTextImp has no method with id '%1'." ).arg( id );
return throwError(exec, msg,KJS::ReferenceError);
}
@@ -274,7 +274,7 @@ KJS::Value TQCanvasTextImp::call( KJS::ExecState *exec, KJS::Object &self, const
KJS::Value TQCanvasTextImp::setText_5( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQString arg0 = extractTQString(exec, args, 0);
+ TQString arg0 = extractTQString(exec, args, 0);
instance->setText(
arg0 );
@@ -285,7 +285,7 @@ KJS::Value TQCanvasTextImp::setText_5( KJS::ExecState *exec, KJS::Object &obj, c
KJS::Value TQCanvasTextImp::setFont_6( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQFont arg0 = extractTQFont(exec, args, 0);
+ TQFont arg0 = extractTQFont(exec, args, 0);
instance->setFont(
arg0 );
@@ -296,7 +296,7 @@ KJS::Value TQCanvasTextImp::setFont_6( KJS::ExecState *exec, KJS::Object &obj, c
KJS::Value TQCanvasTextImp::setColor_7( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQColor arg0 = extractTQColor(exec, args, 0);
+ TQColor arg0 = extractTQColor(exec, args, 0);
instance->setColor(
arg0 );
@@ -307,7 +307,7 @@ KJS::Value TQCanvasTextImp::setColor_7( KJS::ExecState *exec, KJS::Object &obj,
KJS::Value TQCanvasTextImp::text_8( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQString ret;
+ TQString ret;
ret = instance->text( );
return KJS::String( ret );
@@ -365,7 +365,7 @@ KJS::Value TQCanvasTextImp::setTextFlags_13( KJS::ExecState *exec, KJS::Object &
KJS::Value TQCanvasTextImp::boundingRect_14( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TTQRect ret;
+ TQRect ret;
ret = instance->boundingRect( );
return convertToValue( exec, ret );
@@ -375,10 +375,10 @@ KJS::Value TQCanvasTextImp::boundingRect_14( KJS::ExecState *exec, KJS::Object &
KJS::Value TQCanvasTextImp::collidesWith_15( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
// Unsupported parameter const TTQCanvasItem *
return KJS::Value();
- const TTQCanvasItem * arg0; // Dummy
+ const TQCanvasItem * arg0; // Dummy
bool ret;
ret = instance->collidesWith(
@@ -93,25 +93,25 @@ void TQCanvasTextImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
}
/**
- * Extract a TTQCanvasText pointer from an Object.
+ * Extract a TQCanvasText pointer from an Object.
*/
@@ -375,10 +375,10 @@ KJS::Value TQCanvasTextImp::boundingRect_14( KJS::ExecState *exec, KJS::Object &
KJS::Value TQCanvasTextImp::collidesWith_15( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- // Unsupported parameter const TTQCanvasItem *
+ // Unsupported parameter const TQCanvasItem *
return KJS::Value();